Introduction
============

This Zope product provides two new tools for the CMF in order to make MIME
types based transformations on the portal contents, and so an easy to way to
plugin some new transformations for previously unsupported content types. The
provided tools are:

portal_transform (the transform tool)
  handle transformation of data from a mime type to another

A bunch of ready to use transformations are also provided. Look at the
documentation for more information.

Notice this package can also be used as a standalone Python package. If
you've downloaded the Python distribution, you can't make it a Zope
product since Zope files have been removed from this distribution.

This product is an off-spring of the Archetypes project.

Authors
-------

Benjamin Saller <bcsaller@yahoo.com>
Sidnei da Silva  <sidnei@x3ng.com>
Sylvain Thenault <sylvain.thenault@logilab.fr>

